@@ -1,4 +1,4 @@
-# Copyright (c) 2013, 2019, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2013, 2020, Oracle and/or its affiliates.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
@@ -42,15 +42,34 @@ import shutil
 import subprocess
 import errno
 import traceback
+from cpydist.utils import mysql_c_api_info
+from time import sleep
 from distutils.dist import Distribution
 from imp import load_source
 from functools import wraps
 from pkgutil import walk_packages
 
 try:
-    import _mysql_connector
+    from functools import lru_cache
 except ImportError:
-    pass
+    def lru_cache(*args, **kwargs):
+        """A Python 2.7 replacement for lru_cache
+        """
+        cache = dict()
+        def decorator_lru_cache(func):
+            @wraps(func)
+            def memoized_func(*args, **kwargs):
+                if args in cache:
+                    return cache[args]
+                result = func(*args)
+                cache[args] = result
+                return result
+            return memoized_func
+        return decorator_lru_cache
+    try:
+        import _mysql_connector
+    except ImportError:
+        pass
 
 LOGGER_NAME = "myconnpy_tests"
 LOGGER = logging.getLogger(LOGGER_NAME)
@@ -77,8 +96,6 @@ except ImportError:
         LOGGER.error("Could not initialize Python's unittest module")
         sys.exit(1)
 
-from lib.cpy_distutils import mysql_c_api_info
-
 SSL_AVAILABLE = True
 try:
     import ssl
@@ -114,6 +131,7 @@ OPTIONS_INIT = False
 MYSQL_SERVERS_NEEDED = 1
 MYSQL_SERVERS = []
 MYSQL_VERSION = ()
+MYSQL_LICENSE = ""
 MYSQL_VERSION_TXT = ''
 MYSQL_DUMMY = None
 MYSQL_DUMMY_THREAD = None
@@ -233,8 +251,7 @@ def get_test_modules():
     pattern = re.compile('.*test_(.*)')
     for finder, name, is_pkg in walk_packages(__path__, prefix=__name__+'.'):
         if ('.test_' not in name or
-                ('django' in name and not DJANGO_VERSION) or
-                ('cext' in name and not MYSQL_CAPI)):
+                ('django' in name and not DJANGO_VERSION)):
             continue
 
         module_path = os.path.join(finder.path, name.split('.')[-1] + '.py')
@@ -246,6 +263,7 @@ def get_test_modules():
             continue
         except ImportError as exc:
             check_c_extension(exc)
+            continue
         else:
             try:
                 dsc = mod.__doc__.splitlines()[0]
@@ -808,7 +826,8 @@ def setup_logger(logger, debug=False, logfile=None):
     LOGGER.addHandler(handler)
 
 
-def install_connector(root_dir, install_dir, protobuf_include_dir,
+def install_connector(root_dir, install_dir, openssl_include_dir,
+                      openssl_lib_dir, protobuf_include_dir,
                       protobuf_lib_dir, protoc, connc_location=None,
                       extra_compile_args=None, extra_link_args=None,
                       debug=False):
@@ -839,14 +858,18 @@ def install_connector(root_dir, install_dir, protobuf_include_dir,
         'install',
         '--root', install_dir,
         '--install-lib', '.',
-        '--static',
-        '--is-wheel'
     ])
     if os.name == 'nt':
         cmd.extend([
             '--install-data', cmd_build.build_platlib
         ])
 
+    if any((openssl_include_dir, openssl_lib_dir)):
+        cmd.extend([
+            '--with-openssl-include-dir', openssl_include_dir,
+            '--with-openssl-lib-dir', openssl_lib_dir,
+        ])
+
     if any((protobuf_include_dir, protobuf_lib_dir, protoc)):
         cmd.extend([
             '--with-protobuf-include-dir', protobuf_include_dir,
@@ -863,12 +886,15 @@ def install_connector(root_dir, install_dir, protobuf_include_dir,
     if extra_link_args:
         cmd.extend(['--extra-link-args', extra_link_args])
 
+    if debug:
+        cmd.append('--debug')
+
     LOGGER.debug("Installing command: {0}".format(cmd))
     prc = subprocess.Popen(cmd, stdin=subprocess.PIPE,
                            stderr=subprocess.STDOUT, stdout=subprocess.PIPE,
                            cwd=root_dir)
     stdout = prc.communicate()[0]
-    if prc.returncode is not 0:
+    if prc.returncode != 0:
         with open(logfile, 'wb') as logfp:
             logfp.write(stdout)
         LOGGER.error("Failed installing Connector/Python, see {log}".format(
@@ -907,7 +933,7 @@ def check_c_extension(exc=None):
             mysql_config = os.path.join(MYSQL_CAPI, 'bin', 'mysql_config')
         else:
             mysql_config = MYSQL_CAPI
-        lib_dir = mysql_c_api_info(mysql_config)['link_directories']
+        lib_dir = mysql_c_api_info(mysql_config)['link_dirs']
     elif os.path.isdir(MYSQL_CAPI):
         lib_dir = os.path.join(MYSQL_CAPI, 'lib')
     else:
@@ -941,6 +967,77 @@ def check_c_extension(exc=None):
         LOGGER.error("C Extension not available: %s", error_msg)
         sys.exit(1)
 
+
+@lru_cache(maxsize=10, typed=False)
+def is_host_reachable(host):
+    """Attempts to reach a host, by using the ping command.
+    Returns True if success else False.
+    """
+    param_attemps = "-n" if os.name == "nt" else "-c"
+    attemps = "1"
+    command = ["ping", param_attemps, attemps, host]
+    try:
+        return subprocess.call(command) == 0
+    except OSError:
+        return False
+
+
+@lru_cache(maxsize=10, typed=False)
+def is_plugin_available(plugin_name, config_vars=None, in_server=None):
+    """Checks if the plugin name is available
+
+    The given plugin must be able to be load in the server and his status must
+    be "active" be mark as available, in either result Server will be restarted
+    with the default configuration.
+
+    Returns True if plugin an success else False.
+    """
+    available = False
+    server = in_server if in_server else MYSQL_SERVERS[0]
+    plugin_config_vars = config_vars if config_vars else []
+    server_cnf = server._cnf
+    config = get_mysql_config(server.name)
+
+    ext = "dll" if os.name == "nt" else "so"
+    plugin_full_name = "{name}.{ext}".format(name=plugin_name, ext=ext)
+
+    plugin_config = {
+        "plugin-load-add": plugin_full_name,
+    }
+    plugin_config.update(plugin_config_vars)
+    cnf = "\n# is_plugin_available vars:"
+    for key in plugin_config:
+        cnf = "{}\n{}={}".format(cnf, key, plugin_config[key])
+    server_cnf += cnf
+
+    server.stop()
+    server.wait_down()
+
+    try:
+        server.start(my_cnf=server_cnf)
+        server.wait_up()
+        sleep(1)
+        from mysql.connector import MySQLConnection
+        cnx = MySQLConnection(**config)
+        cnx.cmd_query("SHOW PLUGINS")
+        res = cnx.get_rows()
+        for row in res[0]:
+            if row[0] == plugin_name:
+                if row[1] == "ACTIVE":
+                    available = True
+        cnx.cmd_query("UNINSTALL PLUGIN {}".format(plugin_name))
+        cnx.close()
+        return available
+    except:
+        pass
+    finally:
+        server.stop()
+        server.wait_down()
+        server.start(my_cnf=server_cnf)
+        server.wait_up()
+        sleep(1)
+    return available
+
 def check_tls_versions_support(tls_versions):
     """Check whether we can connect with given TLS version
 
