@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2009, 2019, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0, as
@@ -419,7 +419,7 @@ class MySQLCursorTests(tests.TestsCursor):
             'c': int(1281288),
             'd': float(3.14),
             'e': Decimal('3.14'),
-            'f': 'back\slash',  # pylint: disable=W1401
+            'f': r'back\slash',
             'g': 'newline\n',
             'h': 'return\r',
             'i': "'single'",
